# Search Parameters

## Wallhaven

```{eval-rst}
.. autoclass:: xanax.sources.wallhaven.params.SearchParams
   :members:
```

---

## Unsplash

```{eval-rst}
.. autoclass:: xanax.sources.unsplash.params.UnsplashSearchParams
   :members:
```

```{eval-rst}
.. autoclass:: xanax.sources.unsplash.params.UnsplashRandomParams
   :members:
```

---

## Reddit

```{eval-rst}
.. autoclass:: xanax.sources.reddit.params.RedditParams
   :members:
```
